@@ -173,16 +173,17 @@ class Vyos(Main):  # Vyos/EdgeOS specific commands
 set interfaces {{ int.type }} {{ int.name }} address {{ int.ip }}{{ int.mask }} disabled
 {% else %}
 set interfaces {{ int.type }} {{ int.name }} address {{ int.ip }}{{ int.mask }} {% endif -%}
-
 {% if int.desc and int.desc|length %}
 set interfaces {{ int.type }} {{ int.name }} description '{{ int.desc }}'
 {% endif -%}
-
 {%if int.firewall %}{%for fw in int.firewall -%}
 set interfaces {{ int.type }} {{ int.name }} firewall {{ fw.direction }} name '{{ fw.name }}'
 {% endfor -%}
-
+{% endif -%}
 {%if int.type == "wireguard" -%}
+{% if int.port is defined and int.port|length -%}
+set interfaces {{ int.type }} {{ int.name }} port {{ int.port }}
+{% endif -%}
 {% for peer in int.wg_peers -%}
 set interfaces {{ int.type }} {{ int.name }} peer {{ peer.name }} allowed-ips '{{ peer.allowedips }}'
 {% if peer.endpoint is defined and peer.endpoint|length -%}
@@ -194,8 +195,8 @@ set interfaces {{ int.type }} {{ int.name }} peer {{ peer.name }} persistent-kee
 set interfaces {{ int.type }} {{ int.name }} peer {{ peer.name }} pubkey '{{ peer.pubkey }}'
 {% endfor -%}
 {% endif -%}
-{% endif -%}
-{% endfor -%}"""
+{% endfor -%}
+"""
         output = Template(j2template)                                # associates jinja hostname template with output
         rendered = (output.render(interfaces=conf))                  # renders template, with paramater 'conf', and stores output in 'rendered' var
         return Main.conv_jinja_to_arr(rendered)                      # pushes rendered var through 'conv_jinja_to_arr' method, to convert commands to an array (needed for netmiko's bulk_commands)
@@ -220,11 +221,9 @@ set protocols bgp {{ localAS }} neighbor {{ peer.ip }} remote-as {{ peer.remote_
 {%if peer.desc is defined and peer.desc|length -%}
 set protocols bgp {{ localAS }} neighbor {{ peer.ip }} description {{ peer.desc }}
 {% endif -%}
-
 {%if peer.ebgp_multihop is defined and peer.ebgp_multihop|length -%}
 set protocols bgp {{ localAS }} neighbor {{ peer.ip }} ebgp-multihop {{ peer.ebgp_multihop }}
 {% endif -%}
-
 {%if peer.route_maps -%}
 {%for rm in peer.route_maps -%}  
 {%if rm.state == "absent" -%}
